package com.seeyon.apps.ocip.manager;

import java.util.List;

import com.seeyon.ctp.workflow.exception.BPMException;
import com.seeyon.ctp.workflow.wapi.WorkflowApiManager;

import net.joinwork.bpm.definition.BPMProcess;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import com.seeyon.apps.govdoc.constant.GovdocEnum.ExchangeDetailStatus;
import com.seeyon.apps.govdoc.manager.GovdocExchangeManager;
import com.seeyon.apps.govdoc.po.GovdocExchangeDetail;
import com.seeyon.apps.govdoc.po.GovdocExchangeDetailLog;
import com.seeyon.apps.ocip.exchange.edoc.IOCIPExchangeEdocManager;
import com.seeyon.apps.ocip.util.OrgUtil;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.organization.bo.V3xOrgEntity;
import com.seeyon.ctp.organization.bo.V3xOrgLevel;
import com.seeyon.ctp.organization.bo.V3xOrgPost;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.util.UUIDLong;

public class OcipAjaxManagerImpl implements OcipAjaxManager {
	
	private static final Logger  LOGGER     = Logger.getLogger(OcipAjaxManagerImpl.class);
	
	private OrgManager orgManager;
	private GovdocExchangeManager govdocExchangeManager;
	private WorkflowApiManager wapi;
	//客开项目：ocip-公文交换  [验证是否外单位，是:发送公文撤销通知] 作者：wxt.skl 时间：2017年8月2日 星期四  start 
	public boolean validateIsExtUnit(String recOrgid) throws BusinessException {
		try {
			V3xOrgEntity entity = orgManager.getUnitById(Long.parseLong(recOrgid));
			return  OrgUtil.isPlatformEntity(entity);
		} catch (BusinessException e) {
			LOGGER.error("判断是否外单位出错:",e);
		}
		return false;
	}
	
	public String getOcipUnit(String recOrgids) throws BusinessException {
		String ocipUnits = "";
		if(Strings.isNotBlank(recOrgids)){
			try {
				String[] recOrgIdArr = recOrgids.split(",");
				for (String recOrgId : recOrgIdArr) {
					V3xOrgEntity entity = orgManager.getUnitById(Long.parseLong(recOrgId));
					if(OrgUtil.isPlatformEntity(entity)){
						ocipUnits += recOrgId;
					}
				}
			} catch (BusinessException e) {
				LOGGER.error("判断是否外单位出错:",e);
			}
		}
		return ocipUnits;
	}
	public boolean noticeExtUnitRepeal(String exchangeDetailId,String repealComment) throws BusinessException {
		try{
			/** OCIP 1.0-公文交换开始 */
			if(StringUtils.isNotBlank(exchangeDetailId)){
				//修改状态为已经撤销
				GovdocExchangeDetail detail = govdocExchangeManager.getExchangeDetailById(Long.valueOf(exchangeDetailId));
				if(detail!=null){
					IOCIPExchangeEdocManager m = (IOCIPExchangeEdocManager) AppContext.getBean("ocipExchangeEdocManager");
					m.cancelEdoc(exchangeDetailId, repealComment);
					
					//发送撤销通知成功后修改状态为已经撤销
					detail.setStatus(11);
					govdocExchangeManager.updateDetail(detail);
					
					// 记录日志
					GovdocExchangeDetailLog govdocExchangeDetailLog = new GovdocExchangeDetailLog();
					govdocExchangeDetailLog.setDetailId(detail.getId());
					govdocExchangeDetailLog.setId(UUIDLong.longUUID());
					govdocExchangeDetailLog.setUserName(AppContext.currentUserName());
					govdocExchangeDetailLog.setTime(new java.util.Date());
					govdocExchangeDetailLog.setBackOpinion(repealComment);
					govdocExchangeDetailLog.setDescription("进行了撤销操作，交换状态为已撤销");
					govdocExchangeDetailLog.setStatus(ExchangeDetailStatus.hasCancel.getKey());
					govdocExchangeManager.saveDetailLog(govdocExchangeDetailLog);
				}else{
					LOGGER.error("发送详情对象为找到【"+exchangeDetailId+"】，未通知接收单位撤销");
				}
			}else{
				LOGGER.error("跨系统撤销详情id为空，未通知接收单位撤销");
			}
			return true;
			/** OCIP 1.0-公文交换开始 */
		}catch (Exception e) {
			LOGGER.error("通知交换接收单位撤销公文失败:",e);
		}
		return false;
	}
	//客开项目：ocip-公文交换  [验证是否外单位，是:发送公文撤销通知] 作者：wxt.skl 时间：2017年8月2日 星期四  end 

	// OCIP--[增加岗位编码唯一性校验]  作者：wxt.skl 时间：2017年8月14日 星期一 START
 	@Override
	public boolean validateCodePost(String code,String postId) throws BusinessException {
 		List<V3xOrgPost> v3xOrgPostList= orgManager.getAllPosts(AppContext.currentAccountId());
 		if(v3xOrgPostList!=null && !v3xOrgPostList.isEmpty() && StringUtils.isNotBlank(code)){
 			for (V3xOrgPost v3xOrgPost : v3xOrgPostList) {
				if(code.equals(v3xOrgPost.getCode())){
					//修改时排除当前
					if(StringUtils.isNotBlank(postId) && v3xOrgPost.getId()==Long.valueOf(postId).longValue()){
						continue;
					}
					return true;
				}
			}
 		}
		return false;
	}
 	// OCIP--[增加岗位编码唯一性校验]  作者：wxt.skl 时间：2017年8月14日 星期一 START
	
 	// OCIP--[增加职级编码唯一性校验]  作者：wxt.skl 时间：2017年8月14日 星期一 START
 	@Override
 	public boolean validateCodeLevel(String code,String levelId) throws BusinessException {
 		List<V3xOrgLevel> v3xOrgLevelList= orgManager.getAllLevels(AppContext.currentAccountId());
 		if(v3xOrgLevelList!=null && !v3xOrgLevelList.isEmpty() && StringUtils.isNotBlank(code)){
 			for (V3xOrgLevel v3xOrgLevel : v3xOrgLevelList) {
 				if(code.equals(v3xOrgLevel.getCode())){
 					//修改时排除当前
 					if(StringUtils.isNotBlank(levelId) && v3xOrgLevel.getId()==Long.valueOf(levelId).longValue()){
 						continue;
 					}
 					return true;
 				}
 			}
 		}
 		return false;
 	}
 	// OCIP--[增加职级编码唯一性校验]  作者：wxt.skl 时间：2017年8月14日 星期一 END
	@Override
	public boolean getRunningProcess(String processId)
	{
		BPMProcess process = null;
		try {
			process = this.wapi.getBPMProcess(processId);
		} catch (BPMException e) {
			LOGGER.error(e);
		}
		if(process != null)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	public void setOrgManager(OrgManager orgManager) {
		this.orgManager = orgManager;
	}

	public void setGovdocExchangeManager(GovdocExchangeManager govdocExchangeManager) {
		this.govdocExchangeManager = govdocExchangeManager;
	}

	public void setWapi(WorkflowApiManager wapi) {
		this.wapi = wapi;
	}
	
}
